package org.apache.bcel.classfile;

import java.io.ByteArrayInputStream;
import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.charset.StandardCharsets;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/Signature.class */
public final class Signature extends Attribute {
    private int signatureIndex;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/Signature$MyByteArrayInputStream.class */
    public static final class MyByteArrayInputStream extends ByteArrayInputStream {
        MyByteArrayInputStream(String data) {
            super(data.getBytes(StandardCharsets.UTF_8));
        }

        String getData() {
            return new String(this.buf, StandardCharsets.UTF_8);
        }

        void unread() {
            if (this.pos > 0) {
                this.pos--;
            }
        }
    }

    private static boolean identStart(int ch) {
        return ch == 84 || ch == 76;
    }

    public static boolean isActualParameterList(String s) {
        return s.startsWith("L") && s.endsWith(">;");
    }

    public static boolean isFormalParameterList(String s) {
        return s.startsWith("<") && s.indexOf(58) > 0;
    }

    private static void matchGJIdent(MyByteArrayInputStream in, StringBuilder buf) {
        int ch;
        matchIdent(in, buf);
        int ch2 = in.read();
        if (ch2 == 60 || ch2 == 40) {
            buf.append((char) ch2);
            matchGJIdent(in, buf);
            while (true) {
                ch = in.read();
                if (ch == 62 || ch == 41) {
                    break;
                }
                if (ch == -1) {
                    throw new IllegalArgumentException("Illegal signature: " + in.getData() + " reaching EOF");
                }
                buf.append(", ");
                in.unread();
                matchGJIdent(in, buf);
            }
            buf.append((char) ch);
        } else {
            in.unread();
        }
        int ch3 = in.read();
        if (identStart(ch3)) {
            in.unread();
            matchGJIdent(in, buf);
        } else if (ch3 == 41) {
            in.unread();
        } else if (ch3 != 59) {
            throw new IllegalArgumentException("Illegal signature: " + in.getData() + " read " + ((char) ch3));
        }
    }

    private static void matchIdent(MyByteArrayInputStream in, StringBuilder buf) {
        int read = in.read();
        int ch = read;
        if (read == -1) {
            throw new IllegalArgumentException("Illegal signature: " + in.getData() + " no ident, reaching EOF");
        }
        if (!identStart(ch)) {
            StringBuilder buf2 = new StringBuilder();
            int count = 1;
            while (Character.isJavaIdentifierPart((char) ch)) {
                buf2.append((char) ch);
                count++;
                ch = in.read();
            }
            if (ch == 58) {
                int skipExpected = "Ljava/lang/Object".length();
                long skipActual = in.skip(skipExpected);
                if (skipActual != skipExpected) {
                    throw new IllegalStateException(String.format("Unexpected skip: expected=%,d, actual=%,d", Integer.valueOf(skipExpected), Long.valueOf(skipActual)));
                }
                buf.append((CharSequence) buf2);
                in.read();
                in.unread();
                return;
            }
            for (int i = 0; i < count; i++) {
                in.unread();
            }
            return;
        }
        StringBuilder buf22 = new StringBuilder();
        int ch2 = in.read();
        while (true) {
            buf22.append((char) ch2);
            ch2 = in.read();
            if (ch2 == -1 || (!Character.isJavaIdentifierPart((char) ch2) && ch2 != 47)) {
                break;
            }
        }
        buf.append(Utility.pathToPackage(buf22.toString()));
        if (ch2 != -1) {
            in.unread();
        }
    }

    public static String translate(String s) {
        StringBuilder buf = new StringBuilder();
        matchGJIdent(new MyByteArrayInputStream(s), buf);
        return buf.toString();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public Signature(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, input.readUnsignedShort(), constantPool);
    }

    public Signature(int nameIndex, int length, int signatureIndex, ConstantPool constantPool) {
        super((byte) 10, nameIndex, length, constantPool);
        this.signatureIndex = signatureIndex;
    }

    public Signature(Signature c) {
        this(c.getNameIndex(), c.getLength(), c.getSignatureIndex(), c.getConstantPool());
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitSignature(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        return (Attribute) clone();
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.signatureIndex);
    }

    public String getSignature() {
        return super.getConstantPool().getConstantUtf8(this.signatureIndex).getBytes();
    }

    public int getSignatureIndex() {
        return this.signatureIndex;
    }

    public void setSignatureIndex(int signatureIndex) {
        this.signatureIndex = signatureIndex;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        String s = getSignature();
        return "Signature: " + s;
    }
}
